@@ -359,15 +359,16 @@ FILE *fopen_net(const char *path, const char *mode) {
 	int fd = -1;
 	mode_t openmode = -1;
 
-	if (strcmp(mode, "r") == 0) {
+	if (strcmp(mode, "r") == 0 || strcmp(mode, "rb") == 0) {
 		openmode = O_RDONLY;
 	}
-	if (strcmp(mode, "w") == 0) {
+	if (strcmp(mode, "w") == 0 || strcmp(mode, "wb") == 0) {
 		openmode = O_WRONLY;
 	}
 
+	/* open_net() only handles WRONLY and RDONLY... */
 	if (openmode != O_WRONLY && openmode != O_RDONLY) {
-		return(NULL);
+		return(fopen(path, mode));
 	}
 
 	fd = open_net(path, openmode, 0644);
@@ -379,3 +380,7 @@ FILE *fopen_net(const char *path, const char *mode) {
 
 	return(ret);
 }
+
+int fseek_net(FILE *stream, long offset, int whence) {
+	return(-1);
+}
