@@ -44,6 +44,9 @@ ssize_t read_net(int fd, void *buf, size_t count);
 /* ANSI fopen() clone. */
 FILE *fopen_net(const char *path, const char *mode);
 
+/* ANSI fseek() clone. */
+int fseek_net(FILE *stream, long offset, int whence);
+
 #ifdef  __cplusplus
 }
 #endif
